Convert feature abundances to presence / absence
FeaturePresence.RdThis function converts the feature abundance matrix in a mmo
into a binary presence/absence matrix and stores it as a new component
of the mmo (mmo$feature_presence).
FeaturePresence.RdThis function converts the feature abundance matrix in a mmo
into a binary presence/absence matrix and stores it as a new component
of the mmo (mmo$feature_presence).