Get the distance matrix from the mmo based on the specified distance metric
GetDistanceMat.RdRetrieve a feature distance matrix from the mmo
Details
Looks up a dissimilarity matrix stored in the mmo by name. Works with
the three built-in matrices added by AddChemDist() as well as any
custom matrix added via AddCustomDist().