Calculate log2 fold change for a given control group
GetLog2FoldChange.RdThis function calculates and returns a dataframe of log2 fold change values for each group compared to a specified control group. Takes inputs from GetGroupMeans() function.
Examples
if (FALSE) {
fold_change <- GetLog2FoldChange(GetGroupMeans(mmo,
normalization = 'Log'),
control_group = 'Control')
}