mmo
GetNormFeature.Rd
This function retrieves the feature data from the mmo based on the specified normalization method.
GetNormFeature(mmo, normalization)
The mmo
The normalization method to use. Options are 'None','PA', 'Log', 'Meancentered', 'Z', or 'Imputed'
The feature data corresponding to the specified normalization method
if (FALSE) { feature_data <- GetNormFeature(mmo, normalization = 'Log') }