Skip to contents

This function returns the loaded mmo object (visible return). By default it prints basic information about the R version and recorded packages that were present when the object was saved.

Usage

LoadMMO(file, check_session = TRUE, verbose = TRUE)

Arguments

file

Path to an RDS file created with SaveMMO

check_session

Logical; if TRUE and save-time session info is present, print a short summary (default: TRUE)

verbose

Logical; print messages about saved session info when available (default: TRUE)

Value

The loaded mmo object (list)