Log-normalize the peak area in the mmo
LogNormalization.RdThis function applies log2 transformation to the peak area in the feature data of the mmo.
Run ReplaceZero() before this function to avoid -Inf values.
mmoLogNormalization.RdThis function applies log2 transformation to the peak area in the feature data of the mmo.
Run ReplaceZero() before this function to avoid -Inf values.