Skip to contents

This function normalizes the peak area in the feature data of the mmo by the mass of each sample, provided in the metadata. The feature data is replaced by (original value * mean mass) / sample mass.

Usage

MassNormalization(mmo)

Arguments

mmo

The mmo

Value

The mmo with normalized feature data (mmo$feature_data)

Examples

if (FALSE) {
mmo <- MassNormalization(mmo)
}