Mean-center the peak area in the mmo
MeancenterNormalization.RdThis function applies mean-centering to the peak area in the feature data
of the mmo. Mean-centering is performed per feature (row) across samples.
Features with zero variance are returned as all zeros and are reported in a warning.