PlotNPCStackedBar
PlotNPCStackedBar.RdThis function generates a stacked bar plot showing the count of features in each group categorized by NPC_pathway.
It uses the mmo with sirius annotation and normalized data.
Make sure you don't run ReplaceZero() before using this function, as it may remove presence/absence information.
Arguments
- mmo
The
mmowith sirius annotation and normalized data- group_col
The column name in metadata to use for grouping samples
- outdir
The output file path for the stacked bar plot (e.g., 'NPC_stacked_bar.png')
- width
The width of the output plot
- height
The height of the output plot
- save_output
boolean, whether to save the output plot