Switch the group column in the mmo
SwitchGroup.RdThis function switches the group column in the metadata of the mmo to a new specified column.
The new group column must exist in the metadata file.
mmoSwitchGroup.RdThis function switches the group column in the metadata of the mmo to a new specified column.
The new group column must exist in the metadata file.