Print method for mmos Provides a clean, human-readable overview of an mmo list object instead of dumping the entire list when the object is printed in the console.
print.mmo.RdPrint method for mmos
Provides a clean, human-readable overview of an mmo list object instead of
dumping the entire list when the object is printed in the console.
Usage
# S3 method for class 'mmo'
print(x, ...)