This function retrieves the feature data from the mmo object based on the specified normalization method.
Usage
GetNormFeature(mmo, normalization)
Arguments
- mmo
The mmo object
- normalization
The normalization method to use. Options are 'None','PA', 'Log', 'Meancentered', 'Z', or 'Imputed'
Value
The feature data corresponding to the specified normalization method
Examples
if (FALSE) {
feature_data <- GetNormFeature(mmo, normalization = 'Log')
}