Log-normalize the peak area in the mmo object
LogNormalization.RdThis function applies log2 transformation to the peak area in the feature data of the mmo object. Run ReplaceZero() before this function to avoid -Inf values.
LogNormalization.RdThis function applies log2 transformation to the peak area in the feature data of the mmo object. Run ReplaceZero() before this function to avoid -Inf values.