#' Replace zero and NA values in the mmo object
ReplaceZero.RdThis function replaces zero values in the feature table of an mmo object. Imputed data are stored in mmo$imputed_feature_data, to be used for downsteam analyses including PairwiseComp(). Note that imputation affects normalizations (Log-transformation, etc.), as well as chemical diversity calculations that uses presence/absence.
Usage
ReplaceZero(mmo, method = c("one", "half_min"))