pool_mmo_by_group
pool_mmo_by_group.RdPools sample columns within each group into one pseudo-sample per group. Feature rows are preserved (no filtering of features). Keeps all other slots of the mmo object unchanged by copying mmo first.
pool_mmo_by_group.RdPools sample columns within each group into one pseudo-sample per group. Feature rows are preserved (no filtering of features). Keeps all other slots of the mmo object unchanged by copying mmo first.