Skip to contents

Print method for mmo objects Provides a clean, human-readable overview of an mmo list object instead of dumping the entire list when the object is printed in the console.

Usage

# S3 method for class 'mmo'
print(x, ...)

Arguments

x

An mmo object (a list with components such as feature_data, metadata, pairwise, etc.)

...

Additional arguments passed to other print methods (unused).

Value

Invisibly returns x unchanged.